@@ -6,116 +6,6 @@
 #' @keywords ISO identification
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Identification
 #' @format \code{\link{R6Class}} object.
-#'
-#' @field citation [\code{\link{ISOCitation}}] citation
-#' @field abstract [\code{\link{character}}] abstract
-#' @field purpose [\code{\link{character}}] purpose
-#' @field credit [\code{\link{character}}] credit
-#' @field status [\code{\link{ISOStatus}}] status
-#' @field pointOfContact [\code{\link{ISOResponsibleParty}}] point(s) of contact
-#' @field resourceMaintenance [\code{\link{ISOMaintenanceInformation}}] maintenance information
-#' @field graphicOverview [\code{\link{ISOBrowseGraphic}}] graphic overview(s)
-#' @field resourceFormat [\code{\link{ISOFormat}}] format(s)
-#' @field descriptiveKeywords [\code{\link{ISOKeywords}}] keyword(s)
-#' @field resourceConstraints [\code{\link{ISOConstraints}}] constraint(s)
-#' @field resourceSpecificUsage [\code{\link{ISOUsage}}] usage(s)
-#' @field aggregationInfo [\code{\link{ISOAggregateInformation}}] aggregate information
-#'
-#' @section Methods:
-#' \describe{
-#'  \item{\code{new(xml, element, namespace, defaults)}}{
-#'    This method is used to instantiate an \code{\link{ISOIdentification}}
-#'  }
-#'  \item{\code{setCitation(citation)}}{
-#'    Sets an object of class \code{\link{ISOCitation}}
-#'  }
-#'  \item{\code{setAbstract(abstract, locales)}}{
-#'    Sets an abstract (object of class "character"). Locale names can be 
-#'    specified as \code{list} with the \code{locales} argument.
-#'  }
-#'  \item{\code{setPurpose(purpose, locales)}}{
-#'    Sets a purpose (object of class "character"). Locale names can be 
-#'    specified as \code{list} with the \code{locales} argument.
-#'  }
-#'  \item{\code{addCredit(credit, locales)}}{
-#'    Adds a credit (object of class "character"). Locale names can be 
-#'    specified as \code{list} with the \code{locales} argument.
-#'  }
-#'  \item{\code{delCredit(credit, locales)}}{
-#'    Deletes a credit (object of class "character"). Locale names can be 
-#'    specified as \code{list} with the \code{locales} argument.
-#'  }
-#'  \item{\code{addStatus(status)}}{
-#'    Adds a status, as object of class "character" or class \code{\link{ISOStatus}}. If
-#'    an object of class "character" is specified, it must match the accepted
-#'    progress status values \code{ISOStatus$values()}.
-#'  }
-#'  \item{\code{delStatus(status)}}{
-#'    Deletes a status, as object of class "character" or class \code{\link{ISOStatus}}. If
-#'    an object of class "character" is specified, it must match the accepted
-#'    progress status values \code{ISOStatus$values()}.
-#'  }
-#'  \item{\code{addPointOfContact(pointOfContact)}}{
-#'    Adds an object of class \code{\link{ISOResponsibleParty}}
-#'  }
-#'  \item{\code{delPointOfContact(pointOfContact)}}{
-#'    Deletes an object of class \code{\link{ISOResponsibleParty}}
-#'  }
-#'  \item{\code{addResourceMaintenance(resourceMaintenance)}}{
-#'    Adds a resource maintenance information as object of class 
-#'    \code{\link{ISOMaintenanceInformation}}.
-#'  }
-#'  \item{\code{setResourceMaintenance(resourceMaintenance)}}{
-#'    Sets a resource maintenance information as object of class 
-#'    \code{\link{ISOMaintenanceInformation}}.
-#'  }
-#'  \item{\code{delResourceMaintenance(resourceMaintenance)}}{
-#'    Deletes a resource maintenance information as object of class 
-#'    \code{\link{ISOMaintenanceInformation}}.
-#'  }
-#'  \item{\code{addGraphicOverview(graphicOverview)}}{
-#'    Adds an object of class \code{\link{ISOBrowseGraphic}}
-#'  }
-#'  \item{\code{setGraphicOverview(graphicOverview)}}{
-#'    Sets an object of class \code{\link{ISOBrowseGraphic}}
-#'  }
-#'  \item{\code{delGraphicOverview(graphicOverview)}}{
-#'    Deletes an object of class \code{\link{ISOBrowseGraphic}}
-#'  }
-#'  \item{\code{addFormat(format)}}{
-#'    Adds a resource format, object of class \code{\link{ISOFormat}}
-#'  }
-#'  \item{\code{delFormat(format)}}{
-#'    Deletes a resource format, object of class \code{\link{ISOFormat}}
-#'  }
-#'  \item{\code{addKeywords(keywords)}}{
-#'    Adds a set of keywords as object of class \code{\link{ISOKeywords}}
-#'  }
-#'  \item{\code{setKeywords(keywords)}}{
-#'    Sets a set of keywords as object of class \code{\link{ISOKeywords}}
-#'  }
-#'  \item{\code{delKeywords(keywords)}}{
-#'    Deletes a set of keywords as object of class \code{\link{ISOKeywords}}
-#'  }
-#'  \item{\code{addResourceConstraints(resourceConstraints)}}{
-#'    Adds an object extending \code{\link{ISOConstraints}}, either an object of class
-#'    \code{\link{ISOLegalConstraints}} or \code{\link{ISOSecurityConstraints}}
-#'  }
-#'  \item{\code{setResourceConstraints(resourceConstraints)}}{
-#'    Sets an object extending \code{\link{ISOConstraints}}, either an object of class
-#'    \code{\link{ISOLegalConstraints}} or \code{\link{ISOSecurityConstraints}}
-#'  }
-#'  \item{\code{delResourceConstraints(resourceConstraints)}}{
-#'    Deletes an object extending \code{\link{ISOConstraints}}, either an object of class
-#'    \code{\link{ISOLegalConstraints}} or \code{\link{ISOSecurityConstraints}}
-#'  }
-#'  \item{\code{addAggregateInformation(aggregateInfo)}}{
-#'    Adds an object of class \code{\link{ISOAggregateInformation}}
-#'  }
-#'  \item{\code{delAggregateInformation(aggregateInfo)}}{
-#'    Deletes an object of class \code{\link{ISOAggregateInformation}}
-#'  }
-#' }
 #' 
 #' @references 
 #'   ISO 19115:2003 - Geographic information -- Metadata
@@ -130,33 +20,36 @@ ISOIdentification <- R6Class("ISOIdentification",
    ),
    public = list(
      
-     #+ citation: ISOCitation
+     #'@field citation citation: ISOCitation
      citation = NULL,
-     #+ abstract: character
+     #'@field abstract abstract: character
      abstract = NULL,
-     #+ purpose [0..1]: character
+     #'@field purpose purpose [0..1]: character
      purpose = NULL,
-     #+ credit [0..*]: character
+     #'@field credit credit [0..*]: character
      credit = list(),
-     #+ status [0..*]: ISOStatus
+     #'@field status status [0..*]: ISOStatus
      status = list(),
-     #+ pointOfContact [0..*]: ISOResponsibleParty
+     #'@field pointOfContact pointOfContact [0..*]: ISOResponsibleParty
      pointOfContact = list(),
-     #+ resourceMaintenance [0..*]: ISOMaintenanceInformation
+     #'@field resourceMaintenance resourceMaintenance [0..*]: ISOMaintenanceInformation
      resourceMaintenance = list(),
-     #+ graphicOverview [0..*]: ISOBrowseGraphic
+     #'@field graphicOverview graphicOverview [0..*]: ISOBrowseGraphic
      graphicOverview = list(),
-     #+ resourceFormat [0..*]: ISOFormat
+     #'@field resourceFormat resourceFormat [0..*]: ISOFormat
      resourceFormat = list(),
-     #+ descriptiveKeywords [0..*]: ISOKeywords
+     #'@field descriptiveKeywords descriptiveKeywords [0..*]: ISOKeywords
      descriptiveKeywords = list(),
-     #+ resourceConstraints [0..*]: ISOLegalConstraints
+     #'@field resourceConstraints resourceConstraints [0..*]: ISOLegalConstraints
      resourceConstraints = list(),
-     #+ resourceSpecificUsage [0..*]: MD_Usage (ISOUsage - to implement)
+     #'@field resourceSpecificUsage resourceSpecificUsage [0..*]: MD_Usage (ISOUsage - to implement)
      resourceSpecificUsage = list(), #TODO
-     #+ aggregationInfo [0..*]: ISOAggregateInformation
+     #'@field aggregationInfo aggregationInfo [0..*]: ISOAggregateInformation
      aggregationInfo = list(),
      
+     #'@description Initializes object
+     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param defaults defaults list
      initialize = function(xml = NULL, defaults = list()){
        super$initialize(xml, defaults = defaults)
      },
@@ -164,7 +57,8 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_Identification
      #--------------------------------------------------------------------------
      
-     #setCitation
+     #'@description Set citation
+     #'@param citation object of class \link{ISOCitation}
      setCitation = function(citation){
        if(!is(citation, "ISOCitation")){
          stop("The argument should be a 'ISOCitation' object")
@@ -172,7 +66,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        self$citation = citation
      },
      
-     #setAbstract
+     #'@description Set abstract
+     #'@param abstract abstract
+     #'@param locales list of localized abstracts. Default is \code{NULL}
      setAbstract = function(abstract, locales = NULL){
        self$abstract <- abstract
        if(!is.null(locales)){
@@ -180,7 +76,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        }
      },
      
-     #setPurpose
+     #'@description Set purpose
+     #'@param purpose purpose
+     #'@param locales list of localized texts. Default is \code{NULL}
      setPurpose = function(purpose, locales = NULL){
        self$purpose <- purpose
        if(!is.null(locales)){
@@ -188,7 +86,10 @@ ISOIdentification <- R6Class("ISOIdentification",
        }
      },
      
-     #addCredit
+     #'@description Adds credit
+     #'@param credit credit
+     #'@param locales list of localized texts. Default is \code{NULL}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addCredit = function(credit, locales = NULL){
        if(!is.null(locales)){
          credit <- self$createLocalisedProperty(credit, locales)
@@ -196,7 +97,10 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("credit", credit))
      },
      
-     #delCredit
+     #'@description Deletes credit
+     #'@param credit credit
+     #'@param locales list of localized texts. Default is \code{NULL}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delCredit = function(credit, locales = NULL){
        if(!is.null(locales)){
          credit <- self$createLocalisedProperty(credit, locales)
@@ -204,7 +108,10 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$delListElement("credit", credit))
      },
      
-     #addStatus
+     #'@description Adds status
+     #'@param status object of class \link{ISOStatus} or any \link{character} among
+     #' values returned by \code{ISOStatus$values()}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addStatus = function(status){
        if(!is(status,"ISOStatus")){
          status <- ISOStatus$new(value = status)
@@ -212,7 +119,10 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("status", status))
      },
      
-     #delStatus
+     #'@description Deletes status
+     #'@param status object of class \link{ISOStatus} or any \link{character} among
+     #' values returned by \code{ISOStatus$values()}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delStatus = function(status){
        if(!is(status,"ISOStatus")){
          status <- ISOStatus$new(value = status)
@@ -220,7 +130,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$delListElement("status", status))
      },
      
-     #addPointOfContact
+     #'@description Adds point of contact
+     #'@param pointOfContact object of class \link{ISOResponsibleParty}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addPointOfContact = function(pointOfContact){
        if(!is(pointOfContact,"ISOResponsibleParty")){
          stop("The argument should be a 'ISOResponsibleParty' object")
@@ -228,7 +140,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("pointOfContact", pointOfContact))
      },
      
-     #delPointOfContact
+     #'@description Deletes point of contact
+     #'@param pointOfContact object of class \link{ISOResponsibleParty}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delPointOfContact = function(pointOfContact){
        if(!is(pointOfContact,"ISOResponsibleParty")){
          stop("The argument should be a 'ISOResponsibleParty' object")
@@ -239,7 +153,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_MaintenanceInformation
      #--------------------------------------------------------------------------
      
-     #addResourceMaintenance
+     #'@description Adds resource maintenance
+     #'@param resourceMaintenance object of class \link{ISOMaintenanceInformation}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addResourceMaintenance = function(resourceMaintenance){
        if(!is(resourceMaintenance,"ISOMaintenanceInformation")){
          stop("The argument should be a 'ISOMaintenanceInformation' object")
@@ -247,13 +163,18 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("resourceMaintenance", resourceMaintenance))
      },
      
-     #setResourceMaintenance
+     #'@description Set resource maintenance
+     #'@param resourceMaintenance object of class \link{ISOMaintenanceInformation}
+     #'@return \code{TRUE} if set, \code{FALSE} otherwise
      setResourceMaintenance = function(resourceMaintenance){
+       warning("Method 'setResourceMaintenance' is deprecated, please use 'addResourceMaintenance'!")
        self$resourceMaintenance = list()
        return(self$addResourceMaintenance(resourceMaintenance))
      },
      
-     #delResourceMaintenance
+     #'@description Deletes resource maintenance
+     #'@param resourceMaintenance object of class \link{ISOMaintenanceInformation}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delResourceMaintenance = function(resourceMaintenance){
        if(!is(resourceMaintenance,"ISOMaintenanceInformation")){
          stop("The argument should be a 'ISOMaintenanceInformation' object")
@@ -264,7 +185,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_BrowseGraphic
      #--------------------------------------------------------------------------
      
-     #addGraphicOverview
+     #'@description Adds graphic overview
+     #'@param graphicOverview object of class \link{ISOBrowseGraphic}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addGraphicOverview = function(graphicOverview){
        if(!is(graphicOverview,"ISOBrowseGraphic")){
          stop("The argument should be a 'ISOBrowseGraphic' object")
@@ -272,13 +195,18 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("graphicOverview", graphicOverview))
      },
      
-     #setGraphicOverview
+     #'@description Sets graphic overview
+     #'@param graphicOverview object of class \link{ISOBrowseGraphic}
+     #'@return \code{TRUE} if set, \code{FALSE} otherwise
      setGraphicOverview = function(graphicOverview){
+       warning("Method 'setGraphicOverview' is deprecated, please use 'addGraphicOverview'!")
        self$graphicOverview = list()
        return(self$addGraphicOverview(graphicOverview))
      },
      
-     #delGraphicOverview
+     #'@description Deletes graphic overview
+     #'@param graphicOverview object of class \link{ISOBrowseGraphic}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delGraphicOverview = function(graphicOverview){
        if(!is(graphicOverview,"ISOBrowseGraphic")){
          stop("The argument should be a 'ISOBrowseGraphic' object")
@@ -289,7 +217,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_Format
      #--------------------------------------------------------------------------
      
-     #addFormat
+     #'@description Adds format
+     #'@param format object of class \link{ISOFormat}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addFormat = function(format){
        if(!is(format, "ISOFormat")){
          stop("The argument value should an object of class 'ISOFormat'")
@@ -297,7 +227,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("resourceFormat", format))
      },
      
-     #delFormat
+     #'@description Deletes format
+     #'@param format object of class \link{ISOFormat}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delFormat = function(format){
        if(!is(format, "ISOFormat")){
          stop("The argument value should an object of class 'ISOFormat'")
@@ -308,7 +240,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_Keywords
      #--------------------------------------------------------------------------
      
-     #addKeywords
+     #'@description Adds keywords
+     #'@param keywords object of class \link{ISOKeywords}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addKeywords = function(keywords){
        if(!is(keywords, "ISOKeywords")){
          stop("The argument should be a 'ISOKeywords' object")
@@ -316,13 +250,18 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("descriptiveKeywords", keywords))
      },
      
-     #setKeywords
+     #'@description Set keywords
+     #'@param keywords object of class \link{ISOKeywords}
+     #'@return \code{TRUE} if set, \code{FALSE} otherwise
      setKeywords = function(keywords){
+       warning("Method 'setKeywords' is deprecated, please use 'addKeywords'!")
        self$descriptiveKeywords = list()
        return(self$addKeywords(keywords))
      },
      
-     #delKeywords
+     #'@description Deletes keywords
+     #'@param keywords object of class \link{ISOKeywords}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delKeywords = function(keywords){
        if(!is(keywords, "ISOKeywords")){
          stop("The argument should be a 'ISOKeywords' object")
@@ -333,7 +272,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_Constraints
      #--------------------------------------------------------------------------
      
-     #addResourceConstraints
+     #'@description Adds resource constraints
+     #'@param resourceConstraints object of class \link{ISOConstraints}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addResourceConstraints = function(resourceConstraints){
        if(!is(resourceConstraints, "ISOConstraints")){
          stop("The argument should be a 'ISOConstraints' object")
@@ -341,13 +282,18 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("resourceConstraints", resourceConstraints))
      },
      
-     #setResourceConstraints
+     #'@description Sets resource constraints
+     #'@param resourceConstraints object of class \link{ISOConstraints}
+     #'@return \code{TRUE} if set, \code{FALSE} otherwise
      setResourceConstraints = function(resourceConstraints){
+       warning("Method 'setResourceConstraints' is deprecated, please use 'addResourceConstraints'!")
        self$resourceConstraints = list()
        return(self$addResourceConstraints(resourceConstraints))
      },
      
-     #delResourceConstraints
+     #'@description Deletes resource constraints
+     #'@param resourceConstraints object of class \link{ISOConstraints}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delResourceConstraints = function(resourceConstraints){
        if(!is(resourceConstraints, "ISOConstraints")){
          stop("The argument should be 'ISOConstraints' object")
@@ -358,7 +304,9 @@ ISOIdentification <- R6Class("ISOIdentification",
      #MD_AggregateInformation
      #--------------------------------------------------------------------------
      
-     #addAggregateInformation
+     #'@description Adds aggregate information
+     #'@param aggregateInfo object of class \link{ISOAggregateInformation}
+     #'@return \code{TRUE} if added, \code{FALSE} otherwise
      addAggregateInformation = function(aggregateInfo){
        if(!is(aggregateInfo, "ISOAggregateInformation")){
          stop("The argument should be a 'ISOAggregateInformation' object")
@@ -366,7 +314,9 @@ ISOIdentification <- R6Class("ISOIdentification",
        return(self$addListElement("aggregationInfo", aggregateInfo))
      },
      
-     #delAggregateInformation
+     #'@description Deletes aggregate information
+     #'@param aggregateInfo object of class \link{ISOAggregateInformation}
+     #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
      delAggregateInformation = function(aggregateInfo){
        if(!is(aggregateInfo, "ISOAggregateInformation")){
          stop("The argument should be 'ISOAggregateInformation' object")
