@@ -25,11 +25,13 @@ SWEAbstractObject <- R6Class("SWEAbstractObject",
      #'@param attrs attrs
      #'@param defaults defaults
      #'@param wrap wrap
-     initialize = function(xml = NULL, element = NULL, attrs = list(), defaults = list(), wrap = FALSE){
+     #'@param value_as_field whether value should be set as field
+     initialize = function(xml = NULL, element = NULL, attrs = list(), defaults = list(), wrap = TRUE,
+                           value_as_field = FALSE){
        if(is.null(element)) element <- private$xmlElement
        super$initialize(xml, element, namespace = private$xmlNamespacePrefix, 
                         attrs = attrs, defaults = defaults,
-                        wrap = wrap, value_as_field = TRUE)
+                        wrap = wrap, value_as_field = value_as_field)
      }
    )                        
 )
\ No newline at end of file
