@@ -39,21 +39,21 @@ SWEText <- R6Class("SWEText",
       super$initialize(xml, element = private$xmlElement,
                        updatable = updatable, optional = optional, definition = definition)
       if(is.null(xml)){
-        self$constraint <- constraint
-        self$value <- value
+        self$setConstraint(constraint)
+        self$setValue(value)
       }
     },
     
     #'@description setConstraint
     #'@param constraint constraint
     setConstraint = function(constraint){
-      self$constraint <- constraint
+      self$constraint <- SWEElement$create(element = "constraint", value = constraint)
     },
     
     #'@description setValue
     #'@param value value
     setValue = function(value){
-      self$value <- value
+      self$value <- SWEElement$create(element = "value", value = value)
     }
   )                        
 )
\ No newline at end of file
