@@ -34,7 +34,7 @@ test_that("encoding",{
   md2 <- ISOFeatureAttribute$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
 
@@ -74,6 +74,6 @@ test_that("encoding - i18n",{
   md2 <- ISOFeatureAttribute$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
\ No newline at end of file
